@@ -15,14 +15,14 @@ class Scanner: public ScannerBase
         int lex();
 
     private:
-        int lex__();
-        int executeAction__(size_t ruleNr);
+        int lex_();
+        int executeAction_(size_t ruleNr);
 
         void print();
         void preCode();     // re-implement this function for code that must 
                             // be exec'ed before the patternmatching starts
 
-        void postCode(PostEnum__);
+        void postCode(PostEnum_);
 };
 
 // $insert scannerConstructors
@@ -37,12 +37,12 @@ inline void Scanner::preCode()
     // optionally replace by your own code
 }
 
-inline void Scanner::postCode(PostEnum__)
+inline void Scanner::postCode(PostEnum_)
 {}
 
 inline void Scanner::print() 
 {
-    print__();
+    print_();
 }
 
 
