@@ -4,7 +4,7 @@
 #include "parser/parser.h"
 using namespace std;
 
-int main(int argc)
+int main(int argc, char **argv)
 {
     Parser parser;
 
