@@ -2,7 +2,7 @@
 
 RuleValue Parser::mathConst()
 {
-    string c = d_scanner.YYText();
+    string c = d_scanner.matched();
 
     return RuleValue(
             c == "E" ?  M_E : 
