@@ -5,7 +5,7 @@
 
 using namespace std;
 
-int main(int argc)
+int main(int argc, char **argv)
 {
     cout << "Enter numbers separated by semicolons. Blanks and tabs are "
                                                                 "ignored.\n"
