@@ -2,7 +2,7 @@
 
 FirstSet &FirstSet::operator+=(FirstSet const &other)
 {
-    *this += static_cast<set<Element const *> const &>(other);
+    *this += other.set();
     d_epsilon |= other.d_epsilon;
     return *this;
 }
