@@ -2,35 +2,6 @@
 
 Generator::Map Generator::s_insert =
 {
-    {"executeactioncases",          &Generator::executeActionCases},
-    {"lex",                         &Generator::lex},
-    {"scanner.h",                   &Generator::scannerH},
-    {"scannerobject",               &Generator::scannerObject},
-    {"baseclass",                   &Generator::baseClass},
-    {"class.h",                     &Generator::classH},
-    {"class.ih",                    &Generator::classIH},
-    {"debug",                       &Generator::debug},
-    {"debugdecl",                   &Generator::debugDecl},
-    {"debugfunctions",              &Generator::debugFunctions},
-    {"debugincludes",               &Generator::debugIncludes},
-    {"debuglookup",                 &Generator::debugLookup},
-    {"errorverbose",                &Generator::errorVerbose},
-    {"idoftag",                     &Generator::idOfTag},
-    {"namespace-open",              &Generator::namespaceOpen},
-    {"namespace-close",             &Generator::namespaceClose},
-    {"namespace-use",               &Generator::namespaceUse},
-    {"polyincludes",                &Generator::polyIncludes},
-    {"polymorphic",                 &Generator::polymorphic},
-    {"polymorphicCode",             &Generator::polymorphicCode},
-    {"polymorphicSpecializations",  &Generator::polymorphicSpecializations},
-    {"preincludes",                 &Generator::preIncludes},
-    {"print",                       &Generator::print},
-    {"prompt",                      &Generator::prompt},
-    {"baseclasscode",               &Generator::baseClassCode},
-    {"actioncases",                 &Generator::actionCases},
-    {"staticdata",                  &Generator::staticData},
-    {"tokens",                      &Generator::tokens},
-    {"warnTagMismatches",           &Generator::warnTagMismatches},
     {"LTYPE",                       &Generator::ltype},
     {"LTYPEclear",                  &Generator::ltypeClear},
     {"LTYPEdata",                   &Generator::ltypeData},
@@ -39,6 +10,40 @@ Generator::Map Generator::s_insert =
     {"LTYPEresize",                 &Generator::ltypeResize},
     {"LTYPEstack",                  &Generator::ltypeStack},
     {"STYPE",                       &Generator::stype},
+    {"actioncases",                 &Generator::actionCases},
+    {"baseclass",                   &Generator::baseClass},
+    {"baseclasscode",               &Generator::baseClassCode},
+    {"class.h",                     &Generator::classH},
+    {"class.ih",                    &Generator::classIH},
+    {"debug",                       &Generator::debug},
+    {"debugdecl",                   &Generator::debugDecl},
+    {"debugfunctions",              &Generator::debugFunctions},
+    {"debugincludes",               &Generator::debugIncludes},
+    {"debuglookup",                 &Generator::debugLookup},
+    {"errorverbose",                &Generator::errorVerbose},
+    {"executeactioncases",          &Generator::executeActionCases},
+    {"idoftag",                     &Generator::idOfTag},
+    {"lex",                         &Generator::lex},
+    {"namespace-close",             &Generator::namespaceClose},
+    {"namespace-open",              &Generator::namespaceOpen},
+    {"namespace-use",               &Generator::namespaceUse},
+    {"notokens",                    &Generator::notokens},
+    {"parserbase",                  &Generator::parserBase},
+    {"polyincludes",                &Generator::polyIncludes},
+    {"polymorphic",                 &Generator::polymorphic},
+    {"polymorphicCode",             &Generator::polymorphicCode},
+    {"polymorphicOpAssignDecl",     &Generator::polymorphicOpAssignDecl},
+    {"polymorphicOpAssignImpl",     &Generator::polymorphicOpAssignImpl},
+    {"polymorphicSpecializations",  &Generator::polymorphicSpecializations},
+    {"preincludes",                 &Generator::preIncludes},
+    {"print",                       &Generator::print},
+    {"prompt",                      &Generator::prompt},
+    {"scanner.h",                   &Generator::scannerH},
+    {"scannerobject",               &Generator::scannerObject},
+    {"staticdata",                  &Generator::staticData},
+    {"tokens",                      &Generator::tokens},
+    {"undefparser",                 &Generator::undefparser},
+    {"warnTagMismatches",           &Generator::warnTagMismatches},
 };
 
 vector<Generator::AtBool> Generator::s_atBol =
