@@ -15,8 +15,12 @@ void Generator::polymorphic(ostream &out) const
         out << "    " << poly.first << ",\n";
 
     out << 
+        "    END_TAG_\n"
         "};\n"
         "\n"
+        "class EndPolyType_\n"
+        "{};\n"
+        "\n"
         "namespace Meta_\n"
         "{\n"
         "\n"
@@ -33,3 +37,9 @@ void Generator::polymorphic(ostream &out) const
     filter(in, out, false);
 }
 
+
+
+
+
+
+
