@@ -7,10 +7,17 @@ void Generator::polymorphicOpAssignDecl(ostream &out) const
     for (auto &poly: d_polymorphic)
         out << 
             setw(8) << "" <<
-                 "SType &operator=(" << poly.second << " const &value);\n" <<
+                "SType &operator=(" << poly.second << " const &value);\n" <<
             setw(8) << "" <<
                 "SType &operator=(" << poly.second << " &&tmp);\n"
             "\n";
+
+    out << 
+        setw(8) << "" <<
+             "SType &operator=(EndPolyType_ const &value);\n" <<
+        setw(8) << "" <<
+            "SType &operator=(EndPolyType_ &&tmp);\n"
+        "\n";
 }
 
 
