@@ -9,11 +9,8 @@ void Generator::tokens(ostream &out) const
 
     key(out);
  
-    if (!tokens.size())
-    {
-        out << "// No symbolic tokens were defined\n";
-        return;
-    }
+    if (tokens.size() == 0)                     // no tokens, but tokens.h is
+        out << "// No symbolic tokens were defined\n";          // written
  
     sort(tokens.begin(), tokens.end(), Terminal::compareValues);
 
