@@ -5,13 +5,13 @@ Next::Solution Next::solveByAssociation() const
     switch (Terminal::downcast(d_symbol)->association())
     {
         default:
-        return UNDECIDED;
+        return Solution::UNDECIDED;
 
         case Terminal::NONASSOC:            // left or nonassoc: reduce first
         case Terminal::LEFT:
-        return REDUCE;
+        return Solution::REDUCE;
 
         case Terminal::RIGHT:               // right assoc.: shift first
-        return SHIFT;
+        return Solution::SHIFT;
     }
 }
