@@ -6,7 +6,7 @@ void Options::setAccessorVariables()
     setBooleans();
     setBasicStrings();
     setPathStrings();
-    setQuotedStrings();
+    setQuotedStrings();         // add " " around pathnames
     setSkeletons();
 
     string value;
