@@ -9,7 +9,7 @@ void Options::setLocationDecl(std::string const &block)
         emsg << "%location-struct or %ltype multiply specified" << endl;
     else
     {
-        d_locationDecl = "struct LTYPE__\n" + block += ";\n";
+        d_locationDecl = "struct LTYPE_\n" + block += ";\n";
         d_lspNeeded = true;
     }
 }
