@@ -1,12 +1,20 @@
+//#define XERR
 #include "parser.ih"
 
-void Parser::setPrecedence(size_t type)
+Parser::STYPE_ Parser::setPrecedence(size_t type)
 {
+    if (d_rules.empty())
+    {
+        emsg << "`%prec " << d_matched << 
+                "': `%prec' requires a non-empty production"  << endl;
+        return STYPE_{};
+    }
+
     Symbol *sp = 0;     // to prevent `sp uninitialized' warning by the
                         // compiler 
 
-    switch (type)
-    {
+    switch (type)       // the %prec argument: either a named operator or
+    {                   //                     a char-operator    
         case IDENTIFIER:
             sp = d_symtab.lookup(d_matched);
         break;
@@ -23,6 +31,9 @@ void Parser::setPrecedence(size_t type)
     else
         emsg << "`%prec " << d_matched << "': `" << d_matched << 
                 "' must be a declared terminal token" << endl;
+
+    return STYPE_{};
 }
 
 
+
