@@ -28,6 +28,9 @@ class RRConflict
     
     RRData::Vector d_rmReduction;               // RRData of rules to remove
 
+//    size_t d_rrNr;                              // previous first rule nr at a
+//                                                // RR conflict
+
     static size_t  s_nConflicts;                // number of RR conflicts
 
     public:
@@ -45,7 +48,7 @@ class RRConflict
         std::ostream &insert(std::ostream &out) const;
 
         void visitReduction(size_t first);
-        void compareReductions(size_t second);
+        void compareReductions(size_t *rrIndex, size_t second);
 };
 
 inline size_t RRConflict::nConflicts()
