@@ -5,7 +5,7 @@
 
 void Rules::setPrecedence(Terminal const *terminal)
 {
-    if (!d_currentProduction->precedence())
+    if (not d_currentProduction->precedence())
     {
         d_currentProduction->setPrecedence(terminal);
         terminal->used();
