@@ -15,6 +15,6 @@ void Scanner::returnQuoted(void (Scanner::*handler)())
                                     //          hex constant    (hexadecimal)
                                     // why not escape sequence? (escape)
   
-        leave(Parser::QUOTE);
+        leave(Tokens::QUOTE);
     }
 }
