@@ -19,6 +19,7 @@ void SRConflict::handleSRconflict(Next::ConstIter const &next,
     if (precedence == 0)                    // have an explicit precedence
     {
         // solution = Solution::REDUCE;        // force a reduction
+
         solution = Solution::SHIFT;         // force a shift
         forced = true;
         ++s_nConflicts;                     // and a conflict
@@ -50,11 +51,23 @@ void SRConflict::handleSRconflict(Next::ConstIter const &next,
         default:    // case SHIFT:
         break;
     }
-    
+
+    if (d_lastItemIdx == reducibleItemIdx and d_lastNext == next->next())
+    {
+        if (forced)
+            --s_nConflicts;
+        return;
+    }
+
+    d_lastItemIdx = reducibleItemIdx;
+    d_lastNext = next->next();
+
     d_rmReduction.push_back(
-                                RmReduction(reducibleItemIdx, next->next(), 
-                                            next->symbol(), forced
-                                )
-                          );
+        RmReduction{ reducibleItemIdx, next->next(), next->symbol(), forced }
+    );
 }
 
+
+
+
+
