@@ -8,7 +8,8 @@ ostream &SRConflict::insert(ostream &out) const
     while ((iter = find_if(iter, end, RmReduction::isForced)) != end)
     {
         out << "Solved SR CONFLICT on " << iter->symbol() << 
-                ": shift to state " << iter->next() << ", removed " << 
+                ":\n"
+                "\tshift to state " << iter->next() << ", removed " << 
                 iter->symbol() << " from LA-set of rule " << 
                 d_itemVector[iter->idx()].nr() << ")\n";
         ++iter;
