@@ -1,27 +1,32 @@
 #include "state.ih"
 
-// Defining states proceeds as follows:
+// Defining states proceeds like this:
 //
 //  0. The initial state is constructed. It contains the augmented grammar's
 //     production rule. This part is realized by the static member
 //
 //          initialState();
 //
-//  1. From the state's kernel item(s) all implied rules are added as
-//     additional state items. This results in a vector of (kernel/non-kernel)
-//     items, as well as per item the numbers of the items that are affected
-//     by this item. This information is used later on to propagate the
-//     LA's. This part is realized by the member
+//     The LA set of the kernel item of state 0 (the item representing the
+//     augmented grammar's production rule `S_$: . S') is by definition equal
+//     to $, representing EOF. This LA set is also initialized by
+//     initialState().
+//
+//  1. Starting from the state's kernel item(s) all implied rules are added as
+//     additional (non-kernel) state items. This results in a vector of
+//     (kernel/non-kernel) items, as well as per item the numbers of the items
+//     that are affected by this item. This information is used later to
+//     compute the LA sets of the items. A set's items are determined from its
+//     kernel items by the member
 //          
 //          setItems()
 //
-//     This fills the StateItem::Vector vector. A StateItem contains
+//     This member fills the StateItem::Vector vector. A StateItem contains
 //
 //         1. an item (production rule, dot position, LA set)
-//         2. a LA-enlarged flag, raised when an item's LA set is enlarged
-//         3. a size_t vector of `dependent' items, indicating which items
+//         2. a size_t vector of `dependent' items, indicating which items
 //            have LA sets that depend on the current item.
-//         4. The size_t field `next' holds the index in d_nextVector,
+//         3. The size_t field `d_nextIdx' holds the index in d_nextVector,
 //            allowing quick access of the d_nextVector element defining the
 //            state having the current item as its kernel. a next of npos
 //            indicates that the item does not belong to a next-kernel.
@@ -29,13 +34,13 @@
 //     E.g., 
 //
 //     StateItem:
-//     ---------------------------------------------------------------
-//     item        LA-enlarged LA-set  dependent   next    next
-//                                     stateitems  state   LA-enlarged
-//     ---------------------------------------------------------------
-//     S* -> . S,  false,      EOF,    (1, 2)      0       true/false
+//     -------------------------------------
+//     item        LA-set  dependent   next 
+//                         stateitems  state
+//     -------------------------------------
+//     S* -> . S,  EOF,    (1, 2)      0    
 //     ...
-//     ---------------------------------------------------------------
+//     -------------------------------------
 //
 //     Also, the d_nextVector vector is filled.
 //
@@ -43,9 +48,9 @@
 //
 //          0. The symbol on which the transition takes place
 //          1. The number of the next state
-//          2. The indices of the StateItem::Vector defining the next
-//                 state's kernel 
-//      
+//          2. A StateItem::Vector object (size_t values) holding indices of 
+//    items in the current state. The elements's indices are the indices of 
+//    (kernel) items of the state to transfer to (the destination index).
 //      E.g., 
 //
 //      Next:
@@ -57,54 +62,42 @@
 //      ...
 //      -------------------------------
 //
-//     Also, the nextOnSymbol() is handled here, and nextOnSymbol will simply
-//     remove the production rules where dot is at the rule's end, since
-//     they will not become part of the next state's kernels.
-//      
 //     Empty production rules don't require special handling as they won't
-//     appear in the Next table, since there's no transition on them. Thus,
-//     the previously mentioned nextOnSymbol() function is no longer
-//     required. 
+//     appear in the Next table, since there's no transition on them.
 //
-//     From these facilities all states are now constructed. LA propagation is
-//     performed after the state construction since LA propagation is an
-//     inherently recursive process, and state construction isn't. State
-//     construction takes place below, in the while loop following the initial
-//     state construction.
+//     From these facilities all states are now constructed. LA sets are
+//     computed following the state construction by the member
+//     determineLAsets. 
 //
-//  2. [cancelled: nextOnSymbol()]
-//
-//  3. Then the lookaheads (LAs)will be propagated over the items in the
-//     current state. This is where previous versions went wrong. LAs are
-//     distributed over and determined for each individual item, and are then
-//     inherited by the next states. Also, LAs can be determined during the
-//     construction of a state, instead of during a separate cycle. LAs are
-//     propagated from the initial state over the dependent StateItems
-//     Lookahead propagation is performed by the member
-//                  
-//          propagateLA()
-//
-//  4. Then, from the Next::Vector constructed at (1) the next states
+//  2. Then, from the Next::Vector constructed at (1) new states
 //     are constructed. This is realized by the member
 //
-//          constructNext()
+//          nextState()
 //
-//     A next state will be constructed only if it wasn't constructed yet. For
-//     a new state, the construct() member will be called. Construct() will
-//     call setItems() and propagateLA(). Otherwise, propagateLA will also be
-//     called for all states having kernels whose next LA-enlarged flag is
-//     set. 
+//     which is called for each of the elements of d_nextVector.  States are
+//     only constructed once. 
+//
+//  3. New states receive their kernel items from the item(s) of the current
+//     state from where a transition is possible. A new state is constructed
+//     by addState, receiving the just constructed set of kernel items from
+//     nextState. 
+//
+//  4. All states are eventually constructed by the loop, shown below, which
+//     ends once the idx loop control variable has reached s_state.size().
+//
+//  5. Once all  states have been constructed, the LA sets of the items of all
+//     states are computed by determineLAsets(). See determinelasets.cc for a
+//     discription of the implemented algorithm.
+//
+//  6. Once all states have been constructed and LA sets have been determined,
+//     conflicts may be located and solved. If the state contains any conflict,
+//     they are resolved and information about these conflicts is stored in an
+//     SRConflict::Vector and/or RRConflict::Vector. Conflicts are identified
+//     and resolved by the member (static)checkConflicts(); See
+//     README.states-and-conflicts for a description of the actions taken by
+//     checkConflicts().
 
-//  5. When all states have been constructed, conflicts are located and
-//     solved. If the state contains any conflict, they are resolved and
-//     information about these conflicts is stored in an SRConflict::Vector
-//     and/or RRConflict::Vector. Conflicts are identified and resolved by the
-//     member
-//          (static)checkConflicts();
-//     See README.states-and-conflicts for a description of the actions taken
-// by checkConflicts().
-
-void State::define()
+void State::define(Rules const &rules)
 {
     Arg &arg = Arg::instance();
 
@@ -121,7 +114,8 @@ void State::define()
         s_state[idx]->construct();  // define all states (starting at state 0)
     while (++idx != s_state.size());
 
-    s_state[0]->propagateLA();      // propagate the LA set
+    // State 0's initial LA set is already set in initialSate.
+    s_state[0]->determineLAsets();
 
     // Set the accept-state:
     //
@@ -163,12 +157,22 @@ void State::define()
     )
     {
         if (SRConflict::nConflicts())
+        {
             wmsg << SRConflict::nConflicts() << 
-                    " Shift/Reduce conflict(s)" << endl;
+                    " Shift/Reduce conflict(s)\n";
+            for (auto state: s_state)
+                state->showSRConflicts(rules);       // inserts into wmsg
+            wmsg << flush;
+        }
 
         if (RRConflict::nConflicts())
+        {
             wmsg << RRConflict::nConflicts() << 
-                    " Reduce/Reduce conflict(s)" << endl;
+                    " Reduce/Reduce conflict(s)" << '\n';
+            for (auto state: s_state)
+                state->showRRConflicts(rules);       // inserts into wmsg
+            wmsg << flush;
+        }
     }
 
     for (auto state: s_state)
